# -*- coding: utf-8 -*-
# Copyright (c) 2021 Intel Corporation
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Ux Logger module."""
import logging

log = logging.getLogger()
log.name = "INC Bench"
log.setLevel(level=logging.CRITICAL)

fh = logging.FileHandler("bench.log")
fh.setLevel(logging.DEBUG)
log.addHandler(fh)


def change_log_level(log_level: int) -> None:
    """Change log level."""
    global log
    log.setLevel(level=log_level)
